Learn R Programming

tnet (version 2.6)

OnlineSocialNetwork.n1899: Onlince Social Network

Description

This network is the Online Social Network-dataset used in my Ph.D. thesis. This network has also been described in Patterns and Dynamics of Users' Behaviour and Interaction: Network Analysis of an Online Community and used in Prominence and control: The weighted rich-club effect and Clustering in weighted networks. The network originate from an online communication network among students at University of California, Irvine. The edgelist includes the users that sent or received at least one message during that period (1,899). A total number of 59,835 online messages were sent among these over 20,296 directed ties.

Usage

OnlineSocialNetwork.n1899.net

Arguments

format

A data frame with three columns. The first is the id of the sender; the second is the id of the receiver; and the third is the weight of the tie.

References

Opsahl, T., Panzarasa, P., 2009. Clustering in weighted networks. Social Networks 31 (2), 155-163, doi: 10.1016/j.socnet.2009.02.002 http://toreopsahl.com/datasets/