Learn R Programming

tnet (version 2.6)

closeness_w: Closeness centrality in a weighted network

Description

This function calculates closeness scores for nodes in a weighted network based on the distance_w.

Usage

closeness_w(net, directed=NULL, precomp.dist=NULL, alpha=1)

Arguments

net
A weighted edgelist
directed
Logical: whether the edgelist is directed or undirected. Default is NULL, then the function detects this parameter.
precomp.dist
If you have already computed the distance matrix using distance_w, you can enter the name of the matrix object here.
alpha
sets the alpha parameter in the generalised measures from Opsahl, T., Agneessens, F., Skvoretz, J., 2010. Node Centrality in Weighted Networks: Generalizing Degree and Shortest Paths. Social Networks.

Value

  • Returns a data.frame with two columns: the first containts the node ids of all the nodes in the edgelist, and the second containts the corresponding closeness scores.

References

http://toreopsahl.com/2009/01/09/average-shortest-distance-in-weighted-networks/

Examples

Run this code
## Load sample data
sampledata <- rbind(
c(1,2,4),
c(1,3,2),
c(2,1,4),
c(2,3,4),
c(2,4,1),
c(2,5,2),
c(3,1,2),
c(3,2,4),
c(4,2,1),
c(5,2,2),
c(5,6,1),
c(6,5,1))

## Run the programme
closeness_w(sampledata)

Run the code above in your browser using DataLab