Learn R Programming

tnet (version 0.0.6)

closeness_w: Closeness in a weighted network

Description

This function calculates closeness scores for a weighted network based on the distance_w.

Usage

closeness_w(edgelist, directed=NULL, precomp.dist=NULL)

Arguments

edgelist
A weighted edgelist
directed
Logical: whether the edgelist is directed or undirected. Default is NULL, then the function detects this parameter.
precomp.dist
If you have already computed the distance matrix using distance_w, you can enter the name of the matrix object here.

Value

  • Returns a distance matrix.

References

t.opsahl@qmul.ac.uk

Examples

Run this code
## Load sample data
sampledata <- rbind(
c(1,2,4),
c(1,3,2),
c(2,1,4),
c(2,3,4),
c(2,4,1),
c(2,5,2),
c(3,1,2),
c(3,2,4),
c(4,2,1),
c(5,2,2),
c(5,6,1),
c(6,5,1))

## Run the programme
closeness_w(sampledata)

Run the code above in your browser using DataLab