Learn R Programming

tnet (version 0.0.6)

clustering_w_barrat: Barrat et al. (2004) generalised local clusering coefficient

Description

This programme provides the outcomes of Barrat et al. (2004) generalised local clusering coefficient. See http://toreopsahl.com/2009/01/23/weighted-local-clustering-coefficient/ for a detailed description. By default it measure the triplet value as the average of the two ties; however it can also define it differently. See the blog post.

Usage

clustering_w_barrat(edgelist, measure = "am")

Arguments

edgelist
A weighted edgelist
measure
The measure-switch control the method used to calculate the value of the triplets. am implies the arithmetic mean method gm implies the geometric mean method mi implies the minimum method ma implies the maximum method This can be c("am", "gm", "mi", "ma")

Value

  • Returns the outcome of the equation presented in the paper for the method specific (measure)

References

t.opsahl@qmul.ac.uk

Examples

Run this code
## Generate a random graph
#density: 300/(100*99)=0.03030303; 
#this should be average from random samples
rg <- rg_w(nodes=100,arcs=300,max.weight=10,directed=FALSE)

## Run clustering function
clustering_w_barrat(rg)

Run the code above in your browser using DataLab