The shortest path length, or geodesic distance, between two nodes in a binary network is the minimum number of steps you need to make to go from one of them to the other. This distance is the quickest connection between nodes when all ties are the same. However, in a weighted network, all ties are not the same.
Usage
distance_w(edgelist, directed=NULL, gconly=TRUE)
Arguments
edgelist
A weighted edgelist
directed
logical, whether the network is directed or undirected. Default is NULL, this means that the function checks whether the edgelist is directed or not.
gconly
logical, whether the function should only be calculated for the giant component. Default is TRUE.